summaryrefslogtreecommitdiffstats
path: root/libkdegames/highscore/kexthighscore.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkdegames/highscore/kexthighscore.h')
-rw-r--r--libkdegames/highscore/kexthighscore.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/libkdegames/highscore/kexthighscore.h b/libkdegames/highscore/kexthighscore.h
index 5809a896..575ab592 100644
--- a/libkdegames/highscore/kexthighscore.h
+++ b/libkdegames/highscore/kexthighscore.h
@@ -51,17 +51,17 @@ KDE_EXPORT void setGameType(uint gameType);
* Configure the highscores.
* @return true if the configuration has been modified and saved
*/
-KDE_EXPORT bool configure(TQWidget *parent);
+KDE_EXPORT bool configure(TQWidget *tqparent);
/**
* Show the highscores lists.
*/
-KDE_EXPORT void show(TQWidget *parent);
+KDE_EXPORT void show(TQWidget *tqparent);
/**
* Submit a score. See @ref Manager for usage example.
*
* @param widget a widget used as parent for error message box.
*/
KDE_EXPORT void submitScore(const Score &score, TQWidget *widget);
@@ -111,7 +111,7 @@ KDE_EXPORT Score firstScore();
* You can replace the score item (for e.g. displaying it differently) with
* setScoreItem or add an item with addScoreItem.
*
- * The players list contains :
+ * The players list tqcontains :
* <ul>
* <li> the player name (as defined by the user in the configuration
* dialog) </li>
@@ -51,17 +51,17 @@ KDE_EXPORT void setGameType(uint gameType);
* Submit a score. See @ref Manager for usage example.
*
- * @param widget a widget used as parent for error message box.
+ * @param widget a widget used as tqparent for error message box.
*/
KDE_EXPORT void submitScore(const Score &score, TQWidget *widget);